Examples
========

.. toctree::
   :maxdepth: 1
   :caption: List of examples

   ../examples/ac/unipolar-prl100.ipynb
   ../examples/diffusion/diffusion.ipynb
   ../examples/egdm/egdm-g1-g2-g3.ipynb
   ../examples/egdm/image-force-prb79.ipynb
   ../examples/egdm/unipolar-prb78.ipynb
   ../examples/ionic/diluted-electrolyte.ipynb
   ../examples/ionic/electrochemical-doping-japplphys113.ipynb
   ../examples/light-emitting/doping-dynamics-orgel12.ipynb
   ../examples/light-emitting/interfacial-feedback-prb66.ipynb
   ../examples/numeric/fprecision.ipynb
   ../examples/numeric/mesh-convergence.ipynb
   ../examples/photovoltaic/transientphotocurrent-traps.ipynb
   ../examples/scl/scl-trapping.ipynb
   ../examples/scl/transient-with-trapping.ipynb
